@@ -14,21 +14,30 @@ from libica.openapi.v2.model.activation_code_detail import ActivationCodeDetail
 from libica.openapi.v2.model.activation_code_detail_list import ActivationCodeDetailList
 from libica.openapi.v2.model.activation_code_detail_usage import ActivationCodeDetailUsage
 from libica.openapi.v2.model.analysis import Analysis
+from libica.openapi.v2.model.analysis_creation_batch import AnalysisCreationBatch
+from libica.openapi.v2.model.analysis_creation_batch_item import AnalysisCreationBatchItem
+from libica.openapi.v2.model.analysis_creation_batch_item_paged_list import AnalysisCreationBatchItemPagedList
+from libica.openapi.v2.model.analysis_creation_batch_item_processing import AnalysisCreationBatchItemProcessing
+from libica.openapi.v2.model.analysis_creation_batch_item_request import AnalysisCreationBatchItemRequest
 from libica.openapi.v2.model.analysis_data import AnalysisData
 from libica.openapi.v2.model.analysis_data_input import AnalysisDataInput
 from libica.openapi.v2.model.analysis_input import AnalysisInput
+from libica.openapi.v2.model.analysis_input_data_mount import AnalysisInputDataMount
 from libica.openapi.v2.model.analysis_input_list import AnalysisInputList
 from libica.openapi.v2.model.analysis_output import AnalysisOutput
 from libica.openapi.v2.model.analysis_output_list import AnalysisOutputList
+from libica.openapi.v2.model.analysis_output_mapping import AnalysisOutputMapping
 from libica.openapi.v2.model.analysis_paged_list import AnalysisPagedList
-from libica.openapi.v2.model.analysis_parameter import AnalysisParameter
+from libica.openapi.v2.model.analysis_parameter_input import AnalysisParameterInput
 from libica.openapi.v2.model.analysis_raw_output import AnalysisRawOutput
 from libica.openapi.v2.model.analysis_reference_data_parameter import AnalysisReferenceDataParameter
 from libica.openapi.v2.model.analysis_step import AnalysisStep
 from libica.openapi.v2.model.analysis_step_list import AnalysisStepList
+from libica.openapi.v2.model.analysis_step_logs import AnalysisStepLogs
 from libica.openapi.v2.model.analysis_storage import AnalysisStorage
 from libica.openapi.v2.model.analysis_storage_list import AnalysisStorageList
 from libica.openapi.v2.model.analysis_tag import AnalysisTag
+from libica.openapi.v2.model.application import Application
 from libica.openapi.v2.model.aws_credentials import AwsCredentials
 from libica.openapi.v2.model.aws_temp_credentials import AwsTempCredentials
 from libica.openapi.v2.model.base_connection import BaseConnection
@@ -50,6 +59,7 @@ from libica.openapi.v2.model.complete_folder_upload_session import CompleteFolde
 from libica.openapi.v2.model.connector import Connector
 from libica.openapi.v2.model.connector_list import ConnectorList
 from libica.openapi.v2.model.country import Country
+from libica.openapi.v2.model.create_analysis_creation_batch import CreateAnalysisCreationBatch
 from libica.openapi.v2.model.create_bundle import CreateBundle
 from libica.openapi.v2.model.create_connector import CreateConnector
 from libica.openapi.v2.model.create_custom_event import CreateCustomEvent
@@ -61,27 +71,38 @@ from libica.openapi.v2.model.create_nextflow_analysis import CreateNextflowAnaly
 from libica.openapi.v2.model.create_notification_channel import CreateNotificationChannel
 from libica.openapi.v2.model.create_notification_subscription import CreateNotificationSubscription
 from libica.openapi.v2.model.create_project import CreateProject
+from libica.openapi.v2.model.create_project_data_linking_batch import CreateProjectDataLinkingBatch
+from libica.openapi.v2.model.create_project_data_linking_batch_item import CreateProjectDataLinkingBatchItem
 from libica.openapi.v2.model.create_project_permission import CreateProjectPermission
 from libica.openapi.v2.model.create_sample import CreateSample
+from libica.openapi.v2.model.create_sample_creation_batch import CreateSampleCreationBatch
+from libica.openapi.v2.model.create_sample_creation_batch_data_item import CreateSampleCreationBatchDataItem
+from libica.openapi.v2.model.create_sample_creation_batch_sample_item import CreateSampleCreationBatchSampleItem
 from libica.openapi.v2.model.create_storage_configuration import CreateStorageConfiguration
 from libica.openapi.v2.model.create_storage_credential import CreateStorageCredential
 from libica.openapi.v2.model.create_temporary_credentials import CreateTemporaryCredentials
+from libica.openapi.v2.model.create_terms_of_use import CreateTermsOfUse
 from libica.openapi.v2.model.create_upload_rule import CreateUploadRule
 from libica.openapi.v2.model.custom_notification_subscription import CustomNotificationSubscription
 from libica.openapi.v2.model.custom_notification_subscription_list import CustomNotificationSubscriptionList
 from libica.openapi.v2.model.cwl_analysis_input import CwlAnalysisInput
+from libica.openapi.v2.model.cwl_analysis_input_json import CwlAnalysisInputJson
 from libica.openapi.v2.model.cwl_analysis_json_input import CwlAnalysisJsonInput
+from libica.openapi.v2.model.cwl_analysis_output_json import CwlAnalysisOutputJson
 from libica.openapi.v2.model.cwl_analysis_structured_input import CwlAnalysisStructuredInput
 from libica.openapi.v2.model.cwl_tool_definition_list import CwlToolDefinitionList
 from libica.openapi.v2.model.data import Data
 from libica.openapi.v2.model.data_details import DataDetails
 from libica.openapi.v2.model.data_format import DataFormat
 from libica.openapi.v2.model.data_format_paged_list import DataFormatPagedList
+from libica.openapi.v2.model.data_id_or_path_list import DataIdOrPathList
 from libica.openapi.v2.model.data_list import DataList
 from libica.openapi.v2.model.data_paged_list import DataPagedList
 from libica.openapi.v2.model.data_tag import DataTag
 from libica.openapi.v2.model.data_transfer import DataTransfer
-from libica.openapi.v2.model.data_transfers import DataTransfers
+from libica.openapi.v2.model.data_transfer_paged_list import DataTransferPagedList
+from libica.openapi.v2.model.data_url_with_path import DataUrlWithPath
+from libica.openapi.v2.model.data_url_with_path_list import DataUrlWithPathList
 from libica.openapi.v2.model.download import Download
 from libica.openapi.v2.model.download_rule import DownloadRule
 from libica.openapi.v2.model.download_rule_list import DownloadRuleList
@@ -105,6 +126,8 @@ from libica.openapi.v2.model.input_parameter import InputParameter
 from libica.openapi.v2.model.input_parameter_list import InputParameterList
 from libica.openapi.v2.model.input_part import InputPart
 from libica.openapi.v2.model.input_part_media_type import InputPartMediaType
+from libica.openapi.v2.model.job import Job
+from libica.openapi.v2.model.job_paged_list import JobPagedList
 from libica.openapi.v2.model.link import Link
 from libica.openapi.v2.model.links import Links
 from libica.openapi.v2.model.load_data_in_base_request import LoadDataInBaseRequest
@@ -118,15 +141,26 @@ from libica.openapi.v2.model.notification_channel import NotificationChannel
 from libica.openapi.v2.model.notification_channel_list import NotificationChannelList
 from libica.openapi.v2.model.notification_subscription import NotificationSubscription
 from libica.openapi.v2.model.notification_subscription_list import NotificationSubscriptionList
+from libica.openapi.v2.model.optional_sample_tags import OptionalSampleTags
 from libica.openapi.v2.model.pipeline import Pipeline
 from libica.openapi.v2.model.pipeline_bundle import PipelineBundle
+from libica.openapi.v2.model.pipeline_html_documentation import PipelineHtmlDocumentation
+from libica.openapi.v2.model.pipeline_language_version import PipelineLanguageVersion
+from libica.openapi.v2.model.pipeline_language_version_list import PipelineLanguageVersionList
 from libica.openapi.v2.model.pipeline_list import PipelineList
 from libica.openapi.v2.model.pipeline_tag import PipelineTag
 from libica.openapi.v2.model.problem import Problem
 from libica.openapi.v2.model.project import Project
 from libica.openapi.v2.model.project_base_table import ProjectBaseTable
 from libica.openapi.v2.model.project_base_table_list import ProjectBaseTableList
+from libica.openapi.v2.model.project_bundle import ProjectBundle
+from libica.openapi.v2.model.project_bundle_list import ProjectBundleList
 from libica.openapi.v2.model.project_data import ProjectData
+from libica.openapi.v2.model.project_data_linking_batch import ProjectDataLinkingBatch
+from libica.openapi.v2.model.project_data_linking_batch_item import ProjectDataLinkingBatchItem
+from libica.openapi.v2.model.project_data_linking_batch_item_paged_list import ProjectDataLinkingBatchItemPagedList
+from libica.openapi.v2.model.project_data_linking_batch_item_processing import ProjectDataLinkingBatchItemProcessing
+from libica.openapi.v2.model.project_data_linking_batch_item_request import ProjectDataLinkingBatchItemRequest
 from libica.openapi.v2.model.project_data_paged_list import ProjectDataPagedList
 from libica.openapi.v2.model.project_list import ProjectList
 from libica.openapi.v2.model.project_paged_list import ProjectPagedList
@@ -145,6 +179,11 @@ from libica.openapi.v2.model.reference_set_list import ReferenceSetList
 from libica.openapi.v2.model.region import Region
 from libica.openapi.v2.model.region_list import RegionList
 from libica.openapi.v2.model.sample import Sample
+from libica.openapi.v2.model.sample_creation_batch import SampleCreationBatch
+from libica.openapi.v2.model.sample_creation_batch_item_paged_list import SampleCreationBatchItemPagedList
+from libica.openapi.v2.model.sample_creation_batch_item_processing import SampleCreationBatchItemProcessing
+from libica.openapi.v2.model.sample_creation_batch_item_request import SampleCreationBatchItemRequest
+from libica.openapi.v2.model.sample_creation_batch_sample_item import SampleCreationBatchSampleItem
 from libica.openapi.v2.model.sample_history import SampleHistory
 from libica.openapi.v2.model.sample_history_list import SampleHistoryList
 from libica.openapi.v2.model.sample_paged_list import SamplePagedList
@@ -152,7 +191,9 @@ from libica.openapi.v2.model.sample_tag import SampleTag
 from libica.openapi.v2.model.schedule_download import ScheduleDownload
 from libica.openapi.v2.model.search_matching_activation_codes_for_cwl_analysis import SearchMatchingActivationCodesForCwlAnalysis
 from libica.openapi.v2.model.search_matching_activation_codes_for_nextflow_analysis import SearchMatchingActivationCodesForNextflowAnalysis
+from libica.openapi.v2.model.sequencing_run import SequencingRun
 from libica.openapi.v2.model.species import Species
+from libica.openapi.v2.model.species_list import SpeciesList
 from libica.openapi.v2.model.storage_bundle import StorageBundle
 from libica.openapi.v2.model.storage_bundle_list import StorageBundleList
 from libica.openapi.v2.model.storage_configuration import StorageConfiguration
@@ -162,6 +203,7 @@ from libica.openapi.v2.model.storage_configuration_with_details_list import Stor
 from libica.openapi.v2.model.storage_credential import StorageCredential
 from libica.openapi.v2.model.storage_credential_list import StorageCredentialList
 from libica.openapi.v2.model.temp_credentials import TempCredentials
+from libica.openapi.v2.model.terms_of_use import TermsOfUse
 from libica.openapi.v2.model.token import Token
 from libica.openapi.v2.model.type import Type
 from libica.openapi.v2.model.type_list import TypeList
@@ -174,5 +216,8 @@ from libica.openapi.v2.model.upload_rule import UploadRule
 from libica.openapi.v2.model.upload_rule_list import UploadRuleList
 from libica.openapi.v2.model.user import User
 from libica.openapi.v2.model.user_list import UserList
+from libica.openapi.v2.model.workflow import Workflow
+from libica.openapi.v2.model.workflow_session import WorkflowSession
+from libica.openapi.v2.model.workflow_session_tag import WorkflowSessionTag
 from libica.openapi.v2.model.workgroup import Workgroup
 from libica.openapi.v2.model.workgroup_list import WorkgroupList
